/*
 * $Id: LoginService.java,v 1.7 2011/03/25 15:33:02 oboehm Exp $
 *
 * Copyright (c) 2010 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 16.04.2010 by oliver (ob@oasd.de)
 */

package patterntesting.sample.jfs2010;

import java.io.IOException;
import java.net.*;

import javax.security.auth.login.LoginException;

import org.apache.commons.logging.*;

import patterntesting.annotation.exception.TestException;

/**
 * @author oliver
 * @since 1.0 (16.04.2010)
 */

public final class LoginService {

    private static final Log log = LogFactory.getLog(LoginService.class);
    
    /** There is no need to instantiate this utility class. */
    private LoginService() {}

    /**
     * This is an example of a (bad designed) login method.
     * If the login fails the returned user will have a null name!
     *
     * @param name the user name, e.g. "oboehm"
     * @param passwd will be ignored in this implementation
     * @return the user
     * @throws IOException e.g. if network is down
     * @throws LoginException the login exception
     */
    @TestException
    public static User login1(final String name, final String passwd)
            throws IOException, LoginException {
        User user = null;
        URL url = getLoginURL(name);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        int rc = connection.getResponseCode();
        log.debug("RC=" + rc);
        if (rc != 404) {
            user = new User(name);
        }
        return user;
    }
    
    /**
     * This is an example of a login method.
     * If the login fails a LoginException will now be thrown!
     *
     * @param name the user name, e.g. "oboehm"
     * @param passwd will be ignored in this implementation
     * @return the user
     * @throws IOException e.g. if network is down
     * @throws LoginException the login exception
     */
    @TestException
    public static User login(final String name, final String passwd) throws IOException,
            LoginException {
        URL url = getLoginURL(name);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        int rc = connection.getResponseCode();
        log.debug(url + ": RC=" + rc);
        if (rc == 404) {
            throw new LoginException(name + ": login failed");
        }
        return new User(name);
    }

    /**
     * For demo purposes we use here the sourceforge URL as dummy URL to
     * simulate a login.
     *
     * @param username e.g. "maxmustermann"
     * @return e.g. "http://maxmustermann.users.sourceforge.net"
     */
    private static URL getLoginURL(final String username) {
        URL url = null;
        String address = "http://" + username + ".users.sourceforge.net/";
        try {
            url = new URL(address);
        } catch (MalformedURLException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return url;
    }

}

