/*
 * $Id: InitServlet.java,v 1.1 2010/06/27 19:13:58 oboehm Exp $
 *
 * Copyright (c) 2010 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 27.06.2010 by oliver (ob@oasd.de)
 */

package patterntesting.sample.jfs2010.web;

import javax.management.JMException;
import javax.servlet.*;
import javax.servlet.http.HttpServlet;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;

import patterntesting.exception.ExceptionFactory;
import patterntesting.runtime.monitor.ClasspathMonitor;

/**
 * This servlet should be loaded during startup of the web application.
 * It registeres some MBeans needed for testing.
 */
public final class InitServlet extends HttpServlet {

    private static final long serialVersionUID = 20090627L;
    private static final Log log = LogFactoryImpl.getLog(InitServlet.class);

	/**
	 * Initializes the web application. It tries to register some MBeans.
	 * 
	 * @param config the ServletConfig
	 * @throws ServletException in case of an error
	 * @see HttpServlet#init(ServletConfig)
	 */
    @Override
	public void init(final ServletConfig config) throws ServletException {
		log.debug("initializing web application...");
        try {
            ExceptionFactory.registerAsMBean();
            ClasspathMonitor.registerAsMBean();
            log.debug("ClasspathMonitor and ExceptionFactory registered at JMX");
        } catch (JMException e) {
            throw new ServletException("MBean registration failed", e);
        }
	}

}
